@@ -43,9 +43,9 @@ def cal_erle(micFile = None,testFile =None, refFile =None,targetType=0):
     -------
 
     """
-    instruct,insamplerate,_ = get_data_of_ctypes_(micFile)
-    teststruct,outsamplerate,_ = get_data_of_ctypes_(testFile)
-    refstruct, refsamplerate, _ = get_data_of_ctypes_(refFile)
+    instruct,insamplerate,_ = get_data_of_ctypes_(micFile,True)
+    teststruct,outsamplerate,_ = get_data_of_ctypes_(testFile,True)
+    refstruct, refsamplerate, _ = get_data_of_ctypes_(refFile,True)
 
     # if refsamplerate != testsamplerate :
     #     raise TypeError('Different format of ref and test files!')
@@ -56,8 +56,7 @@ def cal_erle(micFile = None,testFile =None, refFile =None,targetType=0):
     DR = data_format()
     ERLE,output_std,err,residual_avgdB = c_double(0.0),c_double(0.0),c_double(0.0),c_double(0.0)
     mydll.ERLE_estimation(byref(instruct),byref(teststruct),byref(refstruct),c_double(insamplerate),c_double(outsamplerate),c_double(targetType),byref(ERLE),byref(output_std),byref(residual_avgdB),byref(err))
-    print(err.value)
-    print(ERLE.value,output_std.value,residual_avgdB.value)
+
     if err.value == 0.0:
         return ERLE.value,output_std.value,residual_avgdB.value
     else:
