@@ -32,9 +32,9 @@ def MATCH_AEC(refFile=None, testFile=None, caliFile=None,outFile=None,targetType
     if err.value == 0.0:
         if outFile is not None:
             write_ctypes_data_2_file_(outFile, outStruct,refsamplerate)
-        return delay.value
+        return True
     else:
-        return None
+        return False
 
 
 if __name__ == '__main__':
