@@ -18,8 +18,8 @@ import ctypes
 def cal_attack_release(refFile=None, testFile=None):
     """
     """
-    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile)
+    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,True)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,True)
 
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
@@ -35,7 +35,7 @@ def cal_attack_release(refFile=None, testFile=None):
 
 
 if __name__ == '__main__':
-    file = r'C:\Users\vcloud_avl\Downloads\agc_eva\speech_attackrelease.wav'
-    test = r'C:\Users\vcloud_avl\Downloads\agc_eva\test_attackrelease.wav'
+    file = r'C:\Users\vcloud_avl\Documents\我的POPO\0\speech_attackrelease.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\0\speech_attackrelease.wav'
     print(cal_attack_release(refFile=file,testFile=test))
     pass
\ No newline at end of file
