@@ -22,8 +22,8 @@ def cal_gain_table(refFile=None, testFile=None,targetType=0):
     -------
 
     '''
-    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile)
+    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,True)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,True)
 
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
@@ -42,8 +42,8 @@ def cal_gain_table(refFile=None, testFile=None,targetType=0):
 
 
 if __name__ == '__main__':
-    file = r'C:\Users\vcloud_avl\Downloads\agc_eva\speech_gaintable.wav'
-    test = r'C:\Users\vcloud_avl\Downloads\agc_eva\test.wav'
+    file = r'C:\Users\vcloud_avl\Documents\我的POPO\0\speech_gaintable.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\0\speech_gaintable.wav'
     lim,gain_table,DR = cal_gain_table(refFile=file,testFile=test,targetType=0)
     print(lim,gain_table[0],DR[2])
     print(gain_table,DR)
