@@ -13,8 +13,8 @@ import ctypes
 def cal_music_stablility(refFile=None, testFile=None):
     """
     """
-    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile)
+    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,True)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,True)
 
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
@@ -32,8 +32,8 @@ def cal_music_stablility(refFile=None, testFile=None):
 
 
 if __name__ == '__main__':
-    file = r'C:\Users\vcloud_avl\Downloads\agc_eva\music_stability_.wav'
-    test = r'C:\Users\vcloud_avl\Downloads\agc_eva\test_music_stability.wav'
+    file = r'C:\Users\vcloud_avl\Documents\我的POPO\0\music_stability.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\0\music_stability.wav'
     res = cal_music_stablility(refFile=file,testFile=test)
     for a in res:
         print(a)
