@@ -62,7 +62,7 @@ def isSlience(Filename =None,section=None,channels=1, bits=16, sample_rate=16000
         return False
     else:
         for n in range(len(ins)//480):
-            curdata = curdata[480*n:480*(n+1)]
+            curdata = ins[480*n:480*(n+1)]
             dBrmsValue = get_rms(curdata)#20 * math.log10(get_rms(curdata) / 32767 + 1.0E-6)
             print(dBrmsValue)
             if dBrmsValue > -60:
