@@ -12,8 +12,8 @@ from commFunction import emxArray_real_T,get_data_of_ctypes_
 def cal_snr_music(refFile=None, testFile=None):
     """
     """
-    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile)
+    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,True)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,True)
     if refsamplerate != testsamplerate:
         raise TypeError('Different format of ref and test files!')
     mydll = ctypes.windll.LoadLibrary(sys.prefix + '/snr_music.dll')
