@@ -14,9 +14,9 @@ import ctypes
 def cal_snr_transient(refFile=None, noisetFile=None, testFile=None):
     """
     """
-    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile)
-    noiseStruct,noisesamplerate,_ = get_data_of_ctypes_(noisetFile)
+    refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile,True)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile,True)
+    noiseStruct,noisesamplerate,_ = get_data_of_ctypes_(noisetFile,True)
     if refsamplerate != testsamplerate or refsamplerate!= noisesamplerate:
         raise TypeError('Different format of ref and test files!')
     mydll = ctypes.windll.LoadLibrary(sys.prefix + '/snr_transient.dll')
@@ -31,6 +31,7 @@ def cal_snr_transient(refFile=None, noisetFile=None, testFile=None):
 
 
 if __name__ == '__main__':
+    print(sys.prefix)
     speech = r'C:\Users\vcloud_avl\Documents\我的POPO\nearend_ref.wav'
     noise = r'C:\Users\vcloud_avl\Documents\我的POPO\noise.wav'
     test = r'C:\Users\vcloud_avl\Documents\我的POPO\3_noise_suppression_1655194712.wav'
